"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const node_fetch_1 = require("node-fetch");
class GitHub {
    constructor(oauthToken) {
        this.oauthToken = oauthToken;
    }
    getComments(owner, repository, issueNumber) {
        const commentsUrl = this.getCommentsUrl(owner, repository, issueNumber);
        console.log(`Get comments from url: ${commentsUrl}`);
        return node_fetch_1.default(commentsUrl, {
            headers: {
                "Authorization": `token ${this.oauthToken}`,
                "Content-Type": "application/json",
            },
            method: "GET"
        })
            .then((response) => {
            return response.json();
        });
    }
    deleteComment(owner, repository, commentId) {
        const commentsUrl = this.getCommentsUrl(owner, repository);
        return node_fetch_1.default(`${commentsUrl}/${commentId}`, {
            headers: {
                "Authorization": `token ${this.oauthToken}`,
                "Content-Type": "application/json",
            },
            method: "DELETE"
        });
    }
    postComment(owner, repository, issueNumber, body) {
        const commentsUrl = this.getCommentsUrl(owner, repository, issueNumber);
        return node_fetch_1.default(commentsUrl, {
            body: JSON.stringify({ body }),
            headers: {
                "Authorization": `token ${this.oauthToken}`,
                "Content-Type": "application/json",
            },
            method: "POST"
        })
            .then((response) => {
            return response.json();
        });
    }
    getRepoUrl(owner, repository) {
        return `https://api.github.com/repos/${owner}/${repository}`;
    }
    getIssuesUrl(owner, repository, issueNumber) {
        let url = this.getRepoUrl(owner, repository);
        if (issueNumber) {
            url += `/issues/${issueNumber}`;
        }
        else {
            url += "/issues";
        }
        return url;
    }
    getCommentsUrl(owner, repository, issueNumber) {
        return this.getIssuesUrl(owner, repository, issueNumber) + "/comments";
    }
}
module.exports = GitHub;
